@@ -4,7 +4,8 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION       = '0.02';
+our $SWFED_VERSION = '0.56';
 
 require XSLoader;
 XSLoader::load('SWFEditor', $VERSION);
@@ -18,7 +19,7 @@ sub new {
     return $self;
 }
 
-sub DESTORY {
+sub DESTROY {
     my $self = shift;
     _swf_object_close($self);
 }
@@ -345,7 +346,7 @@ Implemented function list
 
 =item $swfed->get_png_data(int $image_id)
 
-=item $swfed->replace_bitmap_data(hashref \%image_cond | $image_id, string $bitmapdata, string $alphadata = undef, boolean $without_converting = 0)
+=item $swfed->replace_bitmap_data(hashref \%image_cond | $image_id, string $bitmapdata, string $alphadata = undef, \%opts)
 
 =item $swfed->replace_png_data($image_id, $pngdata)
 
@@ -405,6 +406,10 @@ Implemented function list
 
 SWF Editor for PHP: L<http://sourceforge.jp/projects/swfed/>
 
+=head1 RESOURCES
+
+REPOSITORY: L<https://github.com/mix3/p5-SWFEditor/>
+
 =head1 AUTHOR
 
 Wataru Seto(mix3) E<lt>himachocost333@gmail.comE<gt>
